@@ -3,8 +3,8 @@ import math
 from hurry.filesize import size
 
 
-class AbdalNetPy():
-    class AbdalNetCalc():
+class AbdalNetPy:
+    class AbdalNetCalc:
         def __init__(self, size_bytes):
             self.size_bytes = size_bytes
 
@@ -17,7 +17,7 @@ class AbdalNetPy():
             s = round(self.size_bytes / p, 2)
             return "%s %s" % (s, size_name[i])
 
-    class AbdalUnitCalc():
+    class AbdalUnitCalc:
         def __init__(self, size_bytes):
             self.size_bytes = size_bytes
 
